timetokentools.EqualDivisionTimeTokenMaker
==========================================

.. inheritance-diagram:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker
   :private-bases:

.. autoclass:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.is_diminution

.. autoattribute:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.leaf_count

.. autoattribute:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.reverse

    Inherited from :py:class:`timetokentools.TimeTokenMaker <abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker>`

Special Methods
---------------

.. automethod:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.__call__

.. automethod:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.timetokentools.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.EqualDivisionTimeTokenMaker.__repr__

    Inherited from :py:class:`timetokentools.TimeTokenMaker <abjad.tools.timetokentools.TimeTokenMaker.TimeTokenMaker.TimeTokenMaker>`
